@@ -1,6 +1,13 @@
+from typing import Tuple
+
 from collections import Counter
 
 
+__all__: Tuple[str, ...] = (
+    'Sentence',
+)
+
+
 class Sentence:
     """
         The purpose of this class is as follows:
